@@ -25,7 +25,7 @@
 #include "snip.h"
 #include "output.h"
 #include "normalizer_in.h"
-#include "mrb.h"
+#include "ctx_impl_mrb.h"
 #include <stdio.h>
 #include <stdarg.h>
 #include <time.h>
@@ -92,7 +92,7 @@ grn_timeval_now(grn_ctx *ctx, grn_timeval *tv)
   if (clock_gettime(CLOCK_REALTIME, &t)) {
     SERR("clock_gettime");
   } else {
-    tv->tv_sec = (int32_t) t.tv_sec;
+    tv->tv_sec = t.tv_sec;
     tv->tv_nsec = t.tv_nsec;
   }
   return ctx->rc;
@@ -102,7 +102,7 @@ grn_timeval_now(grn_ctx *ctx, grn_timeval *tv)
   struct _timeb tb;
   time(&t);
   _ftime(&tb);
-  tv->tv_sec = (int32_t) t;
+  tv->tv_sec = t;
   tv->tv_nsec = tb.millitm * (GRN_TIME_NSEC_PER_SEC / 1000);
   return GRN_SUCCESS;
 #else /* WIN32 */
@@ -110,7 +110,7 @@ grn_timeval_now(grn_ctx *ctx, grn_timeval *tv)
   if (gettimeofday(&t, NULL)) {
     SERR("gettimeofday");
   } else {
-    tv->tv_sec = (int32_t) t.tv_sec;
+    tv->tv_sec = t.tv_sec;
     tv->tv_nsec = GRN_TIME_USEC_TO_NSEC(t.tv_usec);
   }
   return ctx->rc;
@@ -187,7 +187,7 @@ grn_str2timeval(const char *str, uint32_t str_len, grn_timeval *tv)
   }
   r1 = r2;
 
-  if ((tv->tv_sec = (int32_t) mktime(&tm)) == -1) { return GRN_INVALID_ARGUMENT; }
+  if ((tv->tv_sec = mktime(&tm)) == -1) { return GRN_INVALID_ARGUMENT; }
   if ((r1 + 1) < rend && *r1 == '.') { r1++; }
   uv = grn_atoi(r1, rend, &r2);
   while (r2 < r1 + 6) {
@@ -643,10 +643,12 @@ grn_ctx_fin(grn_ctx *ctx)
       grn_expr_parser_close(ctx);
     }
     if (ctx->impl->values) {
+#ifndef USE_MEMORY_DEBUG
       grn_db_obj *o;
       GRN_ARRAY_EACH(ctx, ctx->impl->values, 0, 0, id, &o, {
         grn_obj_close(ctx, *((grn_obj **)o));
       });
+#endif
       grn_array_close(ctx, ctx->impl->values);
     }
     if (ctx->impl->ios) {
@@ -2011,6 +2013,8 @@ grn_cache_open(grn_ctx *ctx)
                                 sizeof(grn_cache_entry), GRN_OBJ_KEY_VAR_SIZE);
   MUTEX_INIT(cache->mutex);
   cache->max_nentries = GRN_CACHE_DEFAULT_MAX_N_ENTRIES;
+  cache->nfetches = 0;
+  cache->nhits = 0;
 
 exit :
   GRN_API_RETURN(cache);
@@ -2697,16 +2701,8 @@ grn_realloc_default(grn_ctx *ctx, void *ptr, size_t size, const char* file, int
     if (!ptr) { return NULL; }
     grn_alloc_info_check(ptr);
     GRN_ADD_ALLOC_COUNT(-1);
-#if defined(__FreeBSD__) || defined(__APPLE__)
     free(ptr);
-    return NULL;
-#else /* defined(__FreeBSD__) || defined(__APPLE__) */
-    res = realloc(ptr, size);
-    if (res) {
-      GRN_LOG(ctx, GRN_LOG_ALERT, "realloc(%p,%zu)=%p (%s:%d) <%d>", ptr, size, res, file, line, alloc_count);
-      // grn_free(ctx, res, file, line);
-    }
-#endif /* __FreeBSD__ */
+    res = NULL;
   }
   return res;
 }
