@@ -499,7 +499,7 @@ static void
 grn_text_atoj(grn_ctx *ctx, grn_obj *outbuf, grn_content_type output_type,
               grn_obj *obj, grn_id id)
 {
-  int vs;
+  uint32_t vs;
   grn_obj buf;
   if (obj->header.type == GRN_ACCESSOR) {
     grn_accessor *a = (grn_accessor *)obj;
@@ -542,7 +542,7 @@ grn_text_atoj(grn_ctx *ctx, grn_obj *outbuf, grn_content_type output_type,
             grn_obj_get_value(ctx, a->obj, id, &buf);
             idp = (grn_id *)GRN_BULK_HEAD(&buf);
             vs = GRN_BULK_VSIZE(&buf) / sizeof(grn_id);
-            grn_output_array_open(ctx, outbuf, output_type, "COLUMN", vs);
+            grn_output_array_open(ctx, outbuf, output_type, "VECTOR", vs);
             for (; vs--; idp++) {
               grn_text_atoj(ctx, outbuf, output_type, (grn_obj *)a->next, *idp);
             }
@@ -1583,7 +1583,6 @@ grn_output_envelope(grn_ctx *ctx,
                     grn_obj *foot,
                     const char *file,
                     int line)
-
 {
   double started, finished, elapsed;
   grn_obj *expr = NULL;
